<?php
session_start();
include '../db_connect.php';
require_once 'helper.php';

$search = $_GET['search'] ?? '';
$status_filter = $_GET['status'] ?? ''; // Kann 'OFFEN', 'ABGESCHLOSSEN' oder leer sein
$eb_entries_offen = searchEB($search, 'OFFEN'); // Offene EB-Einträge
$eb_entries_abgeschlossen = searchEB($search, 'ABGESCHLOSSEN'); // Abgeschlossene EB-Einträge

$message = $_SESSION['message'] ?? null;
$error = $_SESSION['error'] ?? null;
unset($_SESSION['message'], $_SESSION['error']);
?>
<!DOCTYPE html>
<html lang="de">
<head>
    <meta charset="UTF-8">
    <title>EB-Liste</title>
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <link 
        href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" 
        rel="stylesheet"
    >
</head>
<body>
<?php include 'partials/navbar.php'; ?>
<div class="container my-5">
    <h1 class="text-center text-primary">Übersicht erwartete Wareneingänge (EB)</h1>
    <?php if ($message): ?>
        <div class="alert alert-success text-center"><?= htmlspecialchars($message); ?></div>
    <?php endif; ?>
    <?php if ($error): ?>
        <div class="alert alert-danger text-center"><?= htmlspecialchars($error); ?></div>
    <?php endif; ?>

    <form method="get" class="mb-4 d-flex">
        <input type="hidden" name="action" value="eb_list">
        <input type="text" name="search" class="form-control me-2" placeholder="EB-Nummer oder Artikel suchen..." value="<?= htmlspecialchars($search); ?>">
        <select name="status" class="form-select me-2">
            <option value="">Alle Status</option>
            <option value="OFFEN" <?= ($status_filter === 'OFFEN') ? 'selected' : ''; ?>>Offen</option>
            <option value="ABGESCHLOSSEN" <?= ($status_filter === 'ABGESCHLOSSEN') ? 'selected' : ''; ?>>Abgeschlossen</option>
        </select>
        <button type="submit" class="btn btn-primary">Suchen</button>
    </form>

    <!-- Offene EB-Einträge -->
    <h2 class="text-secondary">Offene EB-Einträge</h2>
    <?php if (!empty($eb_entries_offen)): ?>
        <div class="table-responsive">
            <table class="table table-striped table-bordered">
                <thead>
                    <tr>
                        <th>EB-Nummer</th>
                        <th>Artikel</th>
                        <th>Gesamtmenge (Einheit)</th>
                        <th>Menge offen (Einheit)</th>
                        <th>Status</th>
                        <th>Barcode</th>
                        <th>Aktion</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($eb_entries_offen as $eb): 
                        $einheit = $eb['einheit'] ?? 'Stück';
                        $faktor = (int)($eb['einheit_faktor'] ?? 1);
                        if ($faktor <= 0) $faktor = 1;

                        $menge_gesamt = (int)$eb['menge_gesamt'];
                        $menge_offen = (int)$eb['menge_offen'];

                        // Umrechnung in Stück
                        $menge_gesamt_stueck = $menge_gesamt * $faktor;
                        $menge_offen_stueck = $menge_offen * $faktor;

                        // Barcode SVG generieren
                        $barcode_svg = generateBarcodeSVG($eb['eb_nummer'], 60, 1);
                    ?>
                        <tr>
                            <td><?= htmlspecialchars($eb['eb_nummer']); ?></td>
                            <td><?= htmlspecialchars($eb['name'] . " (SKU: " . $eb['sku'] . ")"); ?></td>
                            <td>
                                <?= $menge_gesamt . " " . htmlspecialchars($einheit); ?><br>
                                <small class="text-muted">(entspricht <?= $menge_gesamt_stueck; ?> Stück)</small>
                            </td>
                            <td>
                                <?= $menge_offen . " " . htmlspecialchars($einheit); ?><br>
                                <small class="text-muted">(entspricht <?= $menge_offen_stueck; ?> Stück)</small>
                            </td>
                            <td><?= htmlspecialchars($eb['status']); ?></td>
                            <td>
                                <!-- Hidden Div zum Speichern des Barcode SVGs -->
                                <div id="barcode-<?= htmlspecialchars($eb['eb_nummer']); ?>" class="d-none">
                                    <?= $barcode_svg; ?>
                                </div>
                                <!-- Button zum Öffnen des Modals -->
                                <button type="button" class="btn btn-sm btn-secondary barcode-btn" data-bs-toggle="modal" data-bs-target="#barcodeModal" data-eb_nummer="<?= htmlspecialchars($eb['eb_nummer']); ?>">
                                    Barcode
                                </button>
                            </td>
                            <td>
                                <a href="index.php?action=wareneingang_prozess&eb_nummer=<?= urlencode($eb['eb_nummer']); ?>" class="btn btn-sm btn-success">Wareneingang buchen</a>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>
    <?php else: ?>
        <p class="text-center text-muted">Keine offenen EB-Einträge gefunden.</p>
    <?php endif; ?>

    <!-- Abgeschlossene EB-Einträge -->
    <h2 class="text-secondary mt-5">Abgeschlossene EB-Einträge</h2>
    <?php if (!empty($eb_entries_abgeschlossen)): ?>
        <div class="table-responsive">
            <table class="table table-striped table-bordered">
                <thead>
                    <tr>
                        <th>EB-Nummer</th>
                        <th>Artikel</th>
                        <th>Gesamtmenge (Einheit)</th>
                        <th>Menge verbucht (Einheit)</th>
                        <th>Status</th>
                        <th>Abgeschlossen am</th>
                        <th>Barcode</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($eb_entries_abgeschlossen as $eb): 
                        $einheit = $eb['einheit'] ?? 'Stück';
                        $faktor = (int)($eb['einheit_faktor'] ?? 1);
                        if ($faktor <= 0) $faktor = 1;

                        $menge_gesamt = (int)$eb['menge_gesamt'];
                        $menge_offen = (int)$eb['menge_offen'];
                        $menge_verbuucht = $menge_gesamt - $menge_offen;

                        // Umrechnung in Stück
                        $menge_gesamt_stueck = $menge_gesamt * $faktor;
                        $menge_verbuucht_stueck = $menge_verbuucht * $faktor;

                        // Abgeschlossen am Datum formatieren, falls vorhanden
                        $abgeschlossen_am = !empty($eb['updated_at']) ? date('d.m.Y H:i', strtotime($eb['updated_at'])) : '-';

                        // Barcode SVG generieren
                        $barcode_svg = generateBarcodeSVG($eb['eb_nummer'], 60, 1);
                    ?>
                        <tr>
                            <td><?= htmlspecialchars($eb['eb_nummer']); ?></td>
                            <td><?= htmlspecialchars($eb['name'] . " (SKU: " . $eb['sku'] . ")"); ?></td>
                            <td>
                                <?= $menge_gesamt . " " . htmlspecialchars($einheit); ?><br>
                                <small class="text-muted">(entspricht <?= $menge_gesamt_stueck; ?> Stück)</small>
                            </td>
                            <td>
                                <?= $menge_verbuucht . " " . htmlspecialchars($einheit); ?><br>
                                <small class="text-muted">(entspricht <?= $menge_verbuucht_stueck; ?> Stück)</small>
                            </td>
                            <td><?= htmlspecialchars($eb['status']); ?></td>
                            <td><?= htmlspecialchars($abgeschlossen_am); ?></td>
                            <td>
                                <!-- Hidden Div zum Speichern des Barcode SVGs -->
                                <div id="barcode-<?= htmlspecialchars($eb['eb_nummer']); ?>" class="d-none">
                                    <?= $barcode_svg; ?>
                                </div>
                                <!-- Button zum Öffnen des Modals -->
                                <button type="button" class="btn btn-sm btn-secondary barcode-btn" data-bs-toggle="modal" data-bs-target="#barcodeModal" data-eb_nummer="<?= htmlspecialchars($eb['eb_nummer']); ?>">
                                    Barcode
                                </button>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>
    <?php else: ?>
        <p class="text-center text-muted">Keine abgeschlossenen EB-Einträge gefunden.</p>
    <?php endif; ?>
</div>

<!-- Bootstrap Modal für den Barcode -->
<div class="modal fade" id="barcodeModal" tabindex="-1" aria-labelledby="barcodeModalLabel" aria-hidden="true">
  <div class="modal-dialog modal-dialog-centered">
    <div class="modal-content">
      <div class="modal-header">
        <h1 class="modal-title fs-5" id="barcodeModalLabel">EB-Barcode</h1>
        <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Schließen"></button>
      </div>
      <div class="modal-body text-center">
        <!-- Platzhalter für den Barcode -->
        <div id="modalBarcodeContent">
            <!-- Der Barcode SVG wird hier eingefügt -->
        </div>
      </div>
      <div class="modal-footer">
        <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Schließen</button>
      </div>
    </div>
  </div>
</div>

<!-- Bootstrap JS und Popper.js -->
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>

<!-- JavaScript zur Handhabung des Barcode-Buttons und Modals -->
<script>
document.addEventListener('DOMContentLoaded', function () {
    var barcodeButtons = document.querySelectorAll('.barcode-btn');
    var modalBarcodeContent = document.getElementById('modalBarcodeContent');

    barcodeButtons.forEach(function(button) {
        button.addEventListener('click', function() {
            var ebNummer = this.getAttribute('data-eb_nummer');
            var barcodeDiv = document.getElementById('barcode-' + ebNummer);
            if (barcodeDiv) {
                modalBarcodeContent.innerHTML = barcodeDiv.innerHTML;
            } else {
                modalBarcodeContent.innerHTML = '<p class="text-danger">Barcode nicht gefunden.</p>';
            }
        });
    });
});
</script>

</body>
</html>
