<?php
session_start();
include '../db_connect.php'; // Verbindung zur Datenbank
require_once 'helper.php';
require_once 'actions.php';

// Prüfen, ob die Installationsdatei existiert und install.lock nicht vorhanden ist
if (file_exists('install.php') && !file_exists('install.lock')) {
    // Weiterleitung zur Installationsseite
    header('Location: install.php');
    exit();
}

// Prüfen, ob der Benutzer eingeloggt ist
$action = $_GET['action'] ?? 'home';

// Aktionen, die ohne Login verfügbar sind (keine, da Installation bereits gehandhabt wird)
$publicActions = [];

// Prüfen, ob die Aktion öffentlich ist oder ob der Benutzer eingeloggt ist
if (!in_array($action, $publicActions)) {
    if (!isset($_SESSION['user_id'])) {
        header('Location: ../login.php');
        exit();
    }
}

// Aktion bestimmen
$action = $_GET['action'] ?? 'home';

// Standardwerte für die Statistiken (optional, falls Tabellen existieren)
$totalLagerplaetze = 0;
$totalBelegung = 0;
$totalKapazitaet = 0;
$freieKapazitaet = 0;
$durchschnittlicheAuslastung = 0;

if (tableExists($pdo, 'lagerplaetze')) {
    $totalLagerplaetze = $pdo->query('SELECT COUNT(*) FROM lagerplaetze')->fetchColumn();
    $totalBelegung = $pdo->query('SELECT SUM(belegung) FROM lagerplaetze')->fetchColumn();
    $totalKapazitaet = $pdo->query('SELECT SUM(kapazitaet) FROM lagerplaetze')->fetchColumn();
    $freieKapazitaet = $totalKapazitaet - $totalBelegung;
    $durchschnittlicheAuslastung = ($totalKapazitaet > 0) ? ($totalBelegung / $totalKapazitaet) * 100 : 0;
}

// Routing
switch ($action) {
    case 'home': // Dashboard
        // Zusätzliche Daten für das Dashboard abrufen
        $allLagerplaetze = getAllLagerplaetze();
        $allArtikel = getAllArtikelMitLagerplaetzen();
        $top5Artikel = getTop5Artikel();
        $latest5EB = getLatest5EB();
        include 'views/dashboard.php';
        break;

    case 'listArticles': // Artikelliste
        listArticles();
        break;

    case 'assignArticle': // Formular anzeigen
        $articles = getArticles();
        $lagerplaetze = getLagerplaetze();
        include 'views/assign_article.php';
        break;

    case 'editArticle':
        if (isset($_GET['id'])) {
            $article = getArticleById($_GET['id']);
            $lagerplaetze = getLagerplaetze();
            $currentLagerplatzId = getArticleLagerplatzId($_GET['id']);
            include 'views/edit_article.php';
        } else {
            $_SESSION['error'] = "Keine Artikel-ID angegeben!";
            header('Location: index.php?action=listArticles');
            exit();
        }
        break;

    case 'updateArticle':
        updateArticle($_POST);
        break;

    case 'lagerplaetze':
        // Neue Lagerplatz-Übersicht
        $lagerplaetze = getLagerplaetzeMitArtikeln();
        include 'views/lagerplaetze.php';
        break;

    case 'createArticle':
        $lagerplaetze = getLagerplaetze();
        include 'views/create_article.php';
        break;

    case 'assignArticleToLagerplatz': // Zuordnung speichern
        assignArticleToLagerplatz($_POST);
        break;

    case 'deleteArticle':
        if (isset($_GET['id'])) {
            deleteArticle($_GET['id']);
        } else {
            $_SESSION['error'] = "Keine Artikel-ID angegeben!";
            header('Location: index.php?action=listArticles');
            exit();
        }
        break;

    case 'saveArticleWithLagerplatz': // Artikel speichern und Lagerplatz zuordnen
        saveArticleWithLagerplatz($_POST);
        break;

    case 'saveArticle': // Artikel speichern
        saveArticle($_POST);
        break;

    case 'viewLagerplaetze': // Lagerplätze anzeigen (optional)
        include 'views/lagerplaetze.php';
        break;

    case 'wareneingang':
        // Ruft die wareneingang.php auf, in der zuerst EB-Nummer abgefragt wird
        include 'views/wareneingang.php'; 
        break;

    case 'wareneingang_buchen':
        buchenWareneingang($_POST);
        break;


    case 'wareneingang_erfassen':
        $articles = getArticles();
        include 'views/wareneingang_erfassen.php';
        break;

    case 'eb_erfassen':
        $articles = getArticles();
        include 'eb_erfassen.php';
        break;

    case 'saveEB':
        saveEB($_POST);
        break;

    case 'eb_confirm':
        include 'eb_confirm.php';
        break;

    case 'eb_list':
        // Wird in eb_list.php selbst abgefragt
        include 'eb_list.php';
        break;

    case 'wareneingang_prozess':
        include 'wareneingang_prozess.php';
        break;

    case 'saveWareneingang':
        saveWareneingang($_POST);
        break;


    case 'processWareneingang':
        processWareneingang($_POST);
        break;

    default: // Unbekannte Aktion
        echo "Unbekannte Aktion!";
        break;
}

/**
 * Funktion zur Überprüfung, ob eine Tabelle existiert.
 */
function tableExists($pdo, $tableName) {
    try {
        $result = $pdo->query("SELECT 1 FROM `$tableName` LIMIT 1");
    } catch (Exception $e) {
        return false;
    }
    return $result !== false;
}
?>
