<!DOCTYPE html>
<html lang="de">
<head>
    <meta charset="UTF-8">
    <title>Artikelliste</title>
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <!-- Bootstrap CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- Bootstrap Icons -->
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.10.5/font/bootstrap-icons.css">
    <style>
        body {
            background-color: #f7f9fc;
            font-family: 'Segoe UI', Tahoma, Geneva, Verdana, sans-serif;
        }
        h1 {
            font-weight: 700;
            margin-bottom: 30px;
        }
        .table th, .table td {
            vertical-align: middle;
        }
        .btn {
            border-radius: 50px;
            font-weight: 500;
        }
        .btn-primary {
            background-color: #007bff;
            border: none;
        }
        .btn-primary:hover {
            background-color: #0069d9;
        }
        .btn-warning {
            background-color: #ffc107;
            border: none;
            color: #212529;
        }
        .btn-warning:hover {
            background-color: #e0a800;
        }
        .btn-danger {
            background-color: #dc3545;
            border: none;
        }
        .btn-danger:hover {
            background-color: #c82333;
        }
        .alert {
            border-radius: 50px;
            font-weight: 500;
        }
        .text-muted {
            opacity: 0.7;
        }
        .info-text {
            font-size: 0.9em;
            color: #555;
        }
    </style>
</head>
<body>
<?php include 'partials/navbar.php'; ?>

<div class="container my-5">
    <h1 class="text-center text-primary">Artikelliste</h1>

    <!-- Meldungen -->
    <?php if (isset($_SESSION['message'])): ?>
        <div class="alert alert-success text-center" role="alert">
            <i class="bi bi-check-circle-fill me-2"></i><?= htmlspecialchars($_SESSION['message']); ?>
        </div>
        <?php unset($_SESSION['message']); ?>
    <?php endif; ?>

    <?php if (isset($_SESSION['error'])): ?>
        <div class="alert alert-danger text-center" role="alert">
            <i class="bi bi-exclamation-triangle-fill me-2"></i><?= htmlspecialchars($_SESSION['error']); ?>
        </div>
        <?php unset($_SESSION['error']); ?>
    <?php endif; ?>

    <!-- Button für neuen Artikel -->
    <div class="d-flex justify-content-between mb-4">
        <a href="index.php?action=createArticle" class="btn btn-primary btn-lg">
            <i class="bi bi-plus-circle me-2"></i> Neuen Artikel erstellen
        </a>
    </div>

    <!-- Artikeltabelle -->
    <?php if (!empty($articles)): ?>
        <div class="table-responsive">
            <table class="table table-bordered table-striped align-middle">
                <thead class="table-light">
                    <tr>
                        <th>ID</th>
                        <th>Name</th>
                        <th>SKU</th>
                        <th>Preis (€)</th>
                        <th>Einheit</th>
                        <th>Faktor</th>
                        <th>Gesamtbestand (Stück)</th>
                        <th>Lagerplätze</th>
                        <th>Erstellt am</th>
                        <th>Aktionen</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($articles as $article):
                        // Einheit und Faktor, falls vorhanden
                        $einheit = $article['einheit'] ?? 'Stück';
                        $faktor = (int)($article['einheit_faktor'] ?? 1);
                        if ($faktor <= 0) { 
                            $faktor = 1; 
                        }
                        // total_stueck kommt jetzt aus der SQL-Abfrage
                        $total_stueck = (int)$article['total_stueck'];

                        // Berechnung der Gesamtmenge in Einheiten und Stück
                        if ($faktor > 1) {
                            $anzahl_einheiten = floor($total_stueck / $faktor);
                            $rest_stueck = $total_stueck % $faktor;
                            $anzeige_einheiten = $anzahl_einheiten . " " . htmlspecialchars($einheit);
                            if ($rest_stueck > 0) {
                                $anzeige_einheiten .= " + " . $rest_stueck . " Stück";
                            }
                        } else {
                            $anzeige_einheiten = $total_stueck . " Stück";
                        }
                    ?>
                        <tr>
                            <td><?= htmlspecialchars($article['id']); ?></td>
                            <td><?= htmlspecialchars($article['name']); ?></td>
                            <td><?= htmlspecialchars($article['sku']); ?></td>
                            <td><?= htmlspecialchars(number_format($article['price'], 2, ',', '.')); ?> €</td>
                            <td><?= htmlspecialchars($einheit); ?></td>
                            <td><?= $faktor; ?></td>
                            <td>
                                <?= $total_stueck; ?> Stück<br>
                                <?php if ($faktor > 1): ?>
                                    <small class="text-muted">(entspricht <?= number_format($anzahl_einheiten, 0, ',', '.'); ?> <?= htmlspecialchars($einheit); ?>)</small>
                                <?php endif; ?>
                            </td>
                            <td>
                                <?php if (!empty($article['lagerplaetze_namen'])): ?>
                                    <?= htmlspecialchars($article['lagerplaetze_namen']); ?>
                                <?php else: ?>
                                    <span class="text-muted">Nicht zugeordnet</span>
                                <?php endif; ?>
                            </td>
                            <td><?= htmlspecialchars(date('d.m.Y H:i', strtotime($article['erstellt_am']))); ?></td>
                            <td class="text-nowrap">
                                <a href="index.php?action=editArticle&id=<?= $article['id']; ?>" class="btn btn-sm btn-warning me-2">
                                    <i class="bi bi-pencil"></i> Bearbeiten
                                </a>
                                <a href="index.php?action=deleteArticle&id=<?= $article['id']; ?>" class="btn btn-sm btn-danger" onclick="return confirm('Möchten Sie diesen Artikel wirklich löschen?');">
                                    <i class="bi bi-trash"></i> Löschen
                                </a>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>

            </table>
        </div>
    <?php else: ?>
        <p class="text-center text-muted">Keine Artikel gefunden.</p>
    <?php endif; ?>
</div>

<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>
