<?php
session_start();
include '../db_connect.php'; // Stellen Sie sicher, dass der Pfad korrekt ist

// Überprüfen, ob der Benutzer angemeldet ist und Administratorrechte hat
if (!isset($_SESSION['user_id']) || !isset($_SESSION['rolle']) || strtolower($_SESSION['rolle']) !== 'admin') {
    header('Location: ../login.php');
    exit();
}

// Nachrichten aus der Sitzung abrufen und löschen
$message = "";
if (isset($_SESSION['message'])) {
    $message = $_SESSION['message'];
    unset($_SESSION['message']);
}

// Verarbeitung der Deinstallationsanfrage
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['action']) && $_POST['action'] === 'deinstall') {
    // Pfad zur install.lock Datei
    $lockFilePath = __DIR__ . '/MODUL/install.lock';
    
    if (file_exists($lockFilePath)) {
        if (unlink($lockFilePath)) {
            $_SESSION['message'] = "Das Modul wurde erfolgreich deinstalliert.";
        } else {
            $_SESSION['message'] = "Fehler: Die Datei 'install.lock' konnte nicht gelöscht werden.";
        }
    } else {
        $_SESSION['message'] = "Das Modul ist nicht installiert.";
    }
    
    // Weiterleitung zurück zum Modul Store
    header('Location: module_store.php');
    exit();
}

// Liste der verfügbaren Module
$availableModules = [
    [
        'name'        => 'Lagerverwaltung Modul',
        'description' => 'Dieses Modul fügt erweiterte Lagerverwaltungsfunktionen hinzu.',
        'version'     => '1.0.0',
        'author'      => 'SMP',
        'image'       => 'img/smp_modul.png', // Pfad zum Modulbild
        'install_link'=> 'MODUL/install.php',
    ],
    // Weitere Module können hier hinzugefügt werden
];

// Funktion zur Überprüfung, ob ein Modul bereits installiert ist
function isModuleInstalled() {
    // Überprüfen, ob die Datei 'install.lock' im Ordner 'MODUL' existiert
    return file_exists(__DIR__ . '/MODUL/install.lock');
}
?>
<!DOCTYPE html>
<html lang="de">
<head>
    <meta charset="UTF-8">
    <title>Modul Store</title>
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <!-- Bootstrap CSS und Icons -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.10.5/font/bootstrap-icons.css">
    <!-- Google Fonts für modernen Look -->
    <link rel="preconnect" href="https://fonts.googleapis.com">
    <link href="https://fonts.googleapis.com/css2?family=Poppins:wght@400;500;700&display=swap" rel="stylesheet">
    <style>
        /* Allgemeines Layout */
        * {
            box-sizing: border-box;
        }
        body {
            margin: 0;
            padding: 0;
            font-family: 'Poppins', sans-serif;
            background-color: #f9f9f9;
            overflow-x: hidden;
        }

        /* Navigation spektakulärer gestalten */
        .navbar {
            background: #ffffff !important; 
            border-bottom: 1px solid #e5e5e5;
        }
        .navbar-brand, .nav-link {
            color: #333333 !important; 
            font-weight: 500;
        }
        .navbar-brand:hover, .nav-link:hover {
            color: #000000 !important;
        }
        .navbar-toggler {
            border: none;
        }

        /* Hero-Sektion mit animiertem Hintergrund */
        .hero-container {
            position: relative;
            text-align: center;
            padding: 60px 20px 80px 20px;
            overflow: hidden;
            color: #fff;
        }
        .hero-bg {
            position: absolute;
            top: 0; left: 0; right: 0; bottom: 0;
            background: linear-gradient(120deg, #6b73ff, #000dff);
            z-index: -1;
        }
        /* Partikel-Animation im Hero-Bereich */
        .hero-bg::after {
            content: "";
            position: absolute;
            top: 0; left: 0; right: 0; bottom: 0;
            background: radial-gradient(circle at 50% 50%, rgba(255,255,255,0.2) 1%, transparent 40%),
                        radial-gradient(circle at 20% 80%, rgba(255,255,255,0.15) 1%, transparent 30%),
                        radial-gradient(circle at 80% 30%, rgba(255,255,255,0.15) 1%, transparent 40%);
            background-repeat: no-repeat;
            animation: floatParticles 10s infinite linear;
        }
        @keyframes floatParticles {
            0% { background-position: 0% 0%, 20% 80%, 80% 30%; }
            50% { background-position: 50% 30%, 40% 60%, 30% 50%; }
            100% { background-position: 0% 0%, 20% 80%, 80% 30%; }
        }

        .hero-container h1 {
            font-size: 3rem;
            margin-bottom: 15px;
            font-weight: 700;
        }
        .hero-container p {
            font-size: 1.2rem;
            margin-bottom: 0;
            font-weight: 300;
        }

        /* Karten Layout - leichtes 3D-Hover */
        .module-card {
            border: none;
            border-radius: 18px;
            overflow: hidden;
            background: #ffffff;
            box-shadow: 0 8px 20px rgba(0, 0, 0, 0.1);
            transition: transform 0.4s cubic-bezier(0.165, 0.84, 0.44, 1), 
                        box-shadow 0.4s cubic-bezier(0.165, 0.84, 0.44, 1);
        }
        .module-card:hover {
            transform: translateY(-8px) scale(1.02);
            box-shadow: 0 16px 28px rgba(0, 0, 0, 0.15);
        }
        .module-image {
            height: 220px;
            object-fit: cover;
            width: 100%;
        }
        .card-body {
            padding: 20px;
        }
        .module-description {
            min-height: 80px;
            font-size: 0.95rem;
            color: #555555;
        }
        .card-title {
            font-size: 1.3rem;
            font-weight: 600;
            margin-bottom: 10px;
        }
        .card-text {
            margin-bottom: 10px;
        }
        .text-muted {
            color: #999999 !important;
        }

        /* Spektakuläre Buttons mit weichem Farbverlauf */
        .btn-primary, .btn-danger {
            border-radius: 30px;
            font-weight: 500;
            padding: 12px 20px;
            font-size: 0.95rem;
            border: none;
            transition: all 0.3s ease;
        }
        .btn-primary {
            background: linear-gradient(135deg, #6b73ff, #000dff);
            color: #fff;
        }
        .btn-primary:hover {
            background: linear-gradient(135deg, #867bff, #2826ff);
        }
        .btn-danger {
            background: linear-gradient(135deg, #ff6961, #cc0b00);
            color: #fff;
        }
        .btn-danger:hover {
            background: linear-gradient(135deg, #ff7b75, #e02513);
        }
        .btn i {
            margin-right: 6px;
        }

        /* Containerbreite */
        .container {
            max-width: 1200px;
        }

        /* Alerts */
        .alert {
            border-radius: 12px;
            font-size: 0.95rem;
        }

        /* Extra Hover-Effekt auf Links */
        a.nav-link, a.btn {
            position: relative;
            z-index: 1;
            text-decoration: none !important;
        }
        a.nav-link::after, a.btn::after {
            content: "";
            position: absolute;
            left: 0; bottom: 0;
            height: 2px;
            width: 100%;
            background: linear-gradient(135deg, #6b73ff, #000dff);
            transform: scaleX(0);
            transform-origin: right;
            transition: transform 0.3s ease;
            z-index: -1;
        }
        a.nav-link:hover::after,
        a.btn:hover::after {
            transform: scaleX(1);
            transform-origin: left;
        }
    </style>
</head>
<body>

<!-- Navigation für Admin-Bereich -->
<nav class="navbar navbar-expand-lg">
    <div class="container">
        <a class="navbar-brand" href="settings.php">
            <i class="bi bi-gear-fill me-2"></i>Einstellungen
        </a>
        <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#adminNav" aria-controls="adminNav" aria-expanded="false" aria-label="Navigation umschalten">
            <span class="navbar-toggler-icon"></span>
        </button>
        <div class="collapse navbar-collapse" id="adminNav">
            <ul class="navbar-nav ms-auto">
                <li class="nav-item">
                    <a class="nav-link" href="settings.php">
                        <i class="bi bi-arrow-left-circle-fill me-1"></i>Zurück zu Einstellungen
                    </a>
                </li>
                <li class="nav-item">
                    <a class="nav-link" href="logout.php">
                        <i class="bi bi-box-arrow-right me-1"></i>Abmelden
                    </a>
                </li>
            </ul>
        </div>
    </div>
</nav>

<!-- Hero Sektion mit animiertem Hintergrund -->
<div class="hero-container">
    <div class="hero-bg"></div>
    <h1>Modul Store</h1>
    <p>Erweitern Sie Ihr System mit zusätzlichen Funktionen – ganz einfach.</p>
</div>

<div class="container my-5">
    <?php if (!empty($message)): ?>
        <div class="alert alert-info alert-dismissible fade show" role="alert">
            <?php echo nl2br(htmlspecialchars($message)); ?>
            <button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Schließen"></button>
        </div>
    <?php endif; ?>

    <div class="row">
        <?php foreach ($availableModules as $module): ?>
            <?php $installed = isModuleInstalled(); ?>
            <div class="col-md-4 mb-4">
                <div class="card module-card h-100">
                    <img src="<?php echo htmlspecialchars($module['image']); ?>" class="card-img-top module-image" alt="<?php echo htmlspecialchars($module['name']); ?>">
                    <div class="card-body d-flex flex-column">
                        <h5 class="card-title"><?php echo htmlspecialchars($module['name']); ?></h5>
                        <p class="card-text module-description"><?php echo htmlspecialchars($module['description']); ?></p>
                        <p class="card-text text-muted">Version: <?php echo htmlspecialchars($module['version']); ?></p>
                        <p class="card-text text-muted">Autor: <?php echo htmlspecialchars($module['author']); ?></p>
                        <div class="mt-auto">
                            <?php if ($installed): ?>
                                <form method="POST" onsubmit="return confirm('Sind Sie sicher, dass Sie dieses Modul deinstallieren möchten?');">
                                    <input type="hidden" name="action" value="deinstall">
                                    <button type="submit" class="btn btn-danger w-100">
                                        <i class="bi bi-trash"></i>Deinstallieren
                                    </button>
                                </form>
                            <?php else: ?>
                                <a href="<?php echo htmlspecialchars($module['install_link']); ?>" class="btn btn-primary w-100">
                                    <i class="bi bi-download"></i>Installieren
                                </a>
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
            </div>
        <?php endforeach; ?>
    </div>
</div>

<!-- Bootstrap JS und Popper.js -->
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>

</body>
</html>
