<?php
// eb_erfassen.php

session_start();
include '../db_connect.php';
require_once 'helper.php';

// Artikel laden
$articles = getArticles();

$message = $_SESSION['message'] ?? null;
$error = $_SESSION['error'] ?? null;
unset($_SESSION['message'], $_SESSION['error']);
?>
<!DOCTYPE html>
<html lang="de">
<head>
    <meta charset="UTF-8">
    <title>EB erfassen</title>
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <link 
        href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" 
        rel="stylesheet"
    >
</head>
<body>
<?php include 'partials/navbar.php'; ?>
<div class="container my-5">
    <h1 class="text-center text-primary">Neuen erwarteten Wareneingang erfassen</h1>
    <?php if ($message): ?>
        <div class="alert alert-success text-center"><?= htmlspecialchars($message); ?></div>
    <?php endif; ?>
    <?php if ($error): ?>
        <div class="alert alert-danger text-center"><?= htmlspecialchars($error); ?></div>
    <?php endif; ?>
    <form action="index.php?action=saveEB" method="post" class="mt-4">
        <!-- Entfernen des EB-Nummer Eingabefelds -->
        
        <div class="mb-3">
            <label class="form-label">Einheit (z. B. Stück, Karton)</label>
            <input type="text" name="einheit" class="form-control" placeholder="z. B. Karton" required>
        </div>
        <div class="mb-3">
            <label class="form-label">Faktor (wie viele Stück pro Einheit?)</label>
            <input type="number" name="einheit_faktor" class="form-control" min="1" value="1" required>
        </div>

        <div class="mb-3">
            <label class="form-label">Artikel</label>
            <select name="artikel_id" class="form-select" required>
                <option value="">Bitte wählen...</option>
                <?php foreach ($articles as $a): 
                    $einheit = $a['einheit'] ?? 'Stück';
                    $faktor = (int)($a['einheit_faktor'] ?? 1);
                    if ($faktor <= 0) $faktor = 1;

                    // Anzeige: Artikelname (SKU:123) (1 Karton = 50 Stück) Beispiel
                    $optionText = $a['name']." (SKU: ".$a['sku'].") (1 ".$einheit." = ".$faktor." Stück)";
                ?>
                    <option value="<?= $a['id']; ?>">
                        <?= htmlspecialchars($optionText); ?>
                    </option>
                <?php endforeach; ?>
            </select>
        </div>
        <div class="mb-3">
            <label class="form-label">Gesamtmenge erwartet</label>
            <input type="number" name="menge_gesamt" class="form-control" min="1" required>
        </div>
        <div class="d-flex justify-content-between mt-4">
            <a href="index.php?action=home" class="btn btn-secondary">Abbrechen</a>
            <button type="submit" class="btn btn-success">Speichern</button>
        </div>
    </form>
</div>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>
