<?php
session_start();
include '../db_connect.php';
require_once 'helper.php';

$message = $_SESSION['message'] ?? null;
$error = $_SESSION['error'] ?? null;
unset($_SESSION['message'], $_SESSION['error']);

$eb_nummer = $_POST['eb_nummer'] ?? '';
$eb_entry = null;

if (!empty($eb_nummer)) {
    $eb_entry = getEBByNummer($eb_nummer);
}

// HIER Lagerplätze laden
$lagerplaetze = getLagerplaetze();
?>
<!DOCTYPE html>
<html lang="de">
<head>
    <meta charset="UTF-8">
    <title>Wareneingang</title>
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <link 
        href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" 
        rel="stylesheet"
    >
</head>
<body>
<?php include 'partials/navbar.php'; ?>
<div class="container my-5">
    <h1 class="text-center text-primary">Wareneingang</h1>
    <?php if ($message): ?>
        <div class="alert alert-success text-center"><?= htmlspecialchars($message); ?></div>
    <?php endif; ?>
    <?php if ($error): ?>
        <div class="alert alert-danger text-center"><?= htmlspecialchars($error); ?></div>
    <?php endif; ?>

    <?php if (!$eb_entry && empty($eb_nummer)): ?>
        <!-- Erster Schritt: EB-Nummer eingeben -->
        <form method="post" class="mt-4">
            <div class="mb-3">
                <label class="form-label">EB-Nummer eingeben</label>
                <input type="text" name="eb_nummer" class="form-control" placeholder="EB20241208-1" required>
            </div>
            <button type="submit" class="btn btn-primary">Suchen</button>
        </form>
    <?php elseif (!$eb_entry && !empty($eb_nummer)): ?>
        <!-- EB wurde gesucht, aber nicht gefunden -->
        <div class="alert alert-warning text-center">
            Kein EB-Eintrag gefunden für "<?= htmlspecialchars($eb_nummer); ?>"
        </div>
        <a href="index.php?action=wareneingang" class="btn btn-secondary">Zurück</a>
    <?php else: ?>
        <!-- EB-Eintrag gefunden, Details anzeigen -->
        <h2 class="mt-4">EB-Nummer: <?= htmlspecialchars($eb_entry['eb_nummer']); ?></h2>
        <p>Artikel: <?= htmlspecialchars($eb_entry['artikel_name'] . " (SKU: " . $eb_entry['artikel_sku'] . ")"); ?></p>
        <p>Gesamtmenge erwartet: <?= (int)$eb_entry['menge_gesamt']; ?></p>
        <p>Menge offen: <?= (int)$eb_entry['menge_offen']; ?></p>
        <p>Einheit: <?= htmlspecialchars($eb_entry['einheit']); ?> (Faktor: <?= (int)$eb_entry['einheit_faktor']; ?>)</p>
        <p>Status: <?= htmlspecialchars($eb_entry['status']); ?></p>

        <?php if ($eb_entry['status'] !== 'VOLL' && $eb_entry['menge_offen'] > 0): ?>
            <form action="index.php?action=wareneingang_buchen" method="post" class="mt-4">
                <input type="hidden" name="eb_nummer" value="<?= htmlspecialchars($eb_entry['eb_nummer']); ?>">
                <div class="mb-3">
                    <label class="form-label">Gelieferte Menge</label>
                    <input type="number" name="gelieferte_menge" class="form-control" min="1" max="<?= (int)$eb_entry['menge_offen']; ?>" required>
                </div>
                <div class="mb-3">
                    <label class="form-label">Lagerplatz</label>
                    <select name="lagerplatz_id" class="form-select" required>
                        <option value="">Bitte wählen...</option>
                        <?php foreach ($lagerplaetze as $lp): ?>
                            <option value="<?= $lp['id']; ?>"><?= htmlspecialchars($lp['name']); ?></option>
                        <?php endforeach; ?>
                    </select>
                </div>
                <div class="mb-3">
                    <label class="form-label">Art der Lieferung</label>
                    <select name="liefer_art" class="form-select" required>
                        <option value="TEIL">TEIL</option>
                        <option value="VOLL">VOLL</option>
                    </select>
                </div>
                <div class="d-flex justify-content-between mt-4">
                    <a href="index.php?action=wareneingang" class="btn btn-secondary">Zurück</a>
                    <button type="submit" class="btn btn-success">Buchen</button>
                </div>
            </form>
        <?php else: ?>
            <div class="alert alert-info text-center">Dieser Wareneingang ist bereits abgeschlossen (VOLL) oder es gibt keine offene Menge mehr.</div>
            <a href="index.php?action=wareneingang" class="btn btn-secondary">Zurück</a>
        <?php endif; ?>
    <?php endif; ?>
</div>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>
