<?php
session_start();
include '../db_connect.php';
require_once 'helper.php';

// Prüfen, ob der Benutzer eingeloggt ist
if (!isset($_SESSION['user_id'])) {
    header('Location: ../login.php');
    exit();
}

// Artikel laden für Dropdown
$articles = getArticles(); // existiert bereits in actions.php

// Meldungen verarbeiten
$message = $_SESSION['message'] ?? null;
$error = $_SESSION['error'] ?? null;
unset($_SESSION['message'], $_SESSION['error']);
?>
<!DOCTYPE html>
<html lang="de">
<head>
    <meta charset="UTF-8">
    <title>Wareneingang erfassen</title>
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <!-- Bootstrap CSS und Icons -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.10.5/font/bootstrap-icons.css">
    <style>
        body {
            background-color: #f7f9fc;
            font-family: 'Segoe UI', Tahoma, Geneva, Verdana, sans-serif;
        }
        h1 {
            font-weight: 700;
            margin-bottom: 30px;
        }
        .btn {
            border-radius: 50px;
            font-weight: 500;
        }
        .card {
            border: none;
            background-color: #ffffff;
            box-shadow: 0 4px 6px rgba(0,0,0,0.1);
            border-radius: 15px;
        }
        .card-body {
            padding: 30px;
        }
        .alert {
            border-radius: 50px;
            font-weight: 500;
        }
    </style>
</head>
<body>
<?php include 'partials/navbar.php'; ?>

<div class="container my-5">
    <h1 class="text-center text-primary">Neuen Wareneingang erfassen</h1>

    <?php if ($message): ?>
        <div class="alert alert-success text-center" role="alert">
            <i class="bi bi-check-circle-fill me-2"></i><?= htmlspecialchars($message); ?>
        </div>
    <?php endif; ?>

    <?php if ($error): ?>
        <div class="alert alert-danger text-center" role="alert">
            <i class="bi bi-exclamation-triangle-fill me-2"></i><?= htmlspecialchars($error); ?>
        </div>
    <?php endif; ?>

    <div class="card">
        <div class="card-body">
            <form action="index.php?action=saveWareneingang" method="post" class="mt-4">
                <div class="mb-3">
                    <label for="eb_nummer" class="form-label">EB-Nummer</label>
                    <input type="text" name="eb_nummer" id="eb_nummer" class="form-control" placeholder="z. B. EB20241208-1" required>
                </div>

                <div class="mb-3">
                    <label for="lieferscheinnummer" class="form-label">Lieferscheinnummer</label>
                    <input type="text" name="lieferscheinnummer" id="lieferscheinnummer" class="form-control" placeholder="Lieferscheinnr." required>
                </div>

                <div class="mb-3">
                    <label for="artikel_id" class="form-label">Artikel</label>
                    <select name="artikel_id" id="artikel_id" class="form-select" required>
                        <option value="">Bitte wählen...</option>
                        <?php foreach ($articles as $article): ?>
                            <option value="<?= $article['id']; ?>">
                                <?= htmlspecialchars($article['name'] . " (SKU: " . $article['sku'] . ")"); ?>
                            </option>
                        <?php endforeach; ?>
                    </select>
                </div>

                <div class="mb-3">
                    <label for="einheit" class="form-label">Einheit (z. B. Stück, Karton)</label>
                    <input type="text" name="einheit" id="einheit" class="form-control" placeholder="z. B. Karton" required>
                </div>

                <div class="mb-3">
                    <label for="menge" class="form-label">Menge</label>
                    <input type="number" name="menge" id="menge" class="form-control" placeholder="Menge" min="1" required>
                </div>

                <div class="mb-3">
                    <label for="status" class="form-label">Status</label>
                    <select name="status" id="status" class="form-select" required>
                        <option value="TEIL">TEIL</option>
                        <option value="VOLL">VOLL</option>
                    </select>
                </div>

                <div class="d-flex justify-content-between mt-4">
                    <a href="index.php?action=home" class="btn btn-secondary btn-lg">
                        <i class="bi bi-arrow-left-circle"></i> Abbrechen
                    </a>
                    <button type="submit" class="btn btn-success btn-lg">
                        <i class="bi bi-check-circle"></i> Speichern
                    </button>
                </div>
            </form>
        </div>
    </div>
</div>

<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>

</body>
</html>
