<?php
session_start();
include 'db_connect.php';

// Funktion zur Überprüfung, ob der Benutzer Administrator ist
function isAdmin($pdo, $userId) {
    $stmt = $pdo->prepare("SELECT rolle FROM mitarbeiter WHERE id = :id LIMIT 1");
    $stmt->execute(['id' => $userId]);
    $user = $stmt->fetch();
    return $user && $user['rolle'] === 'admin';
}

$moduleInstalled = file_exists(__DIR__ . '/MODUL/install.lock');

if (!isset($_SESSION['user_id']) || strtolower($_SESSION['rolle']) !== 'admin') {
    header('Location: index.php'); // Weiterleitung für Nicht-Admins
    exit();
}

// Nachrichtenspeicher
$message = "";

// Benutzer hinzufügen
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['add_user'])) {
    $name         = trim($_POST['name']);
    $email        = trim($_POST['email']);
    $benutzername = trim($_POST['benutzername']);
    $rolle        = $_POST['rolle'];
    $passwort     = password_hash($_POST['passwort'], PASSWORD_BCRYPT);

    if (!empty($name) && !empty($email) && !empty($benutzername) && !empty($rolle) && !empty($_POST['passwort'])) {
        try {
            $stmt = $pdo->prepare("INSERT INTO mitarbeiter (name, email, benutzername, passwort, rolle) VALUES (:name, :email, :benutzername, :passwort, :rolle)");
            $stmt->execute([
                'name'         => $name,
                'email'        => $email,
                'benutzername' => $benutzername,
                'passwort'     => $passwort,
                'rolle'        => $rolle,
            ]);
            $message = "Mitarbeiter erfolgreich hinzugefügt.";
        } catch (PDOException $e) {
            $message = "Fehler beim Hinzufügen des Mitarbeiters.";
        }
    } else {
        $message = "Bitte füllen Sie alle Felder aus.";
    }
}

// Benutzer bearbeiten
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['edit_user'])) {
    $userId = $_POST['user_id'];
    $name   = trim($_POST['name']);
    $email  = trim($_POST['email']);
    $rolle  = $_POST['rolle'];

    // Passwort aktualisieren, falls ein neues eingegeben wurde
    if (!empty($_POST['passwort'])) {
        $passwort = password_hash($_POST['passwort'], PASSWORD_BCRYPT);
        $sql = "UPDATE mitarbeiter 
                SET name = :name, email = :email, rolle = :rolle, passwort = :passwort 
                WHERE id = :id";
        $params = [
            'name'     => $name,
            'email'    => $email,
            'rolle'    => $rolle,
            'passwort' => $passwort,
            'id'       => $userId,
        ];
    } else {
        $sql = "UPDATE mitarbeiter 
                SET name = :name, email = :email, rolle = :rolle 
                WHERE id = :id";
        $params = [
            'name'  => $name,
            'email' => $email,
            'rolle' => $rolle,
            'id'    => $userId,
        ];
    }

    try {
        $stmt = $pdo->prepare($sql);
        $stmt->execute($params);
        $message = "Benutzer erfolgreich aktualisiert.";
    } catch (PDOException $e) {
        $message = "Fehler beim Aktualisieren des Benutzers.";
    }
}

// Benutzer löschen
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['delete_user'])) {
    $userId = $_POST['user_id'];

    try {
        $stmt = $pdo->prepare("DELETE FROM mitarbeiter WHERE id = :id");
        $stmt->execute(['id' => $userId]);
        $message = "Mitarbeiter erfolgreich gelöscht.";
    } catch (PDOException $e) {
        $message = "Fehler beim Löschen des Mitarbeiters.";
    }
}

// Benutzer aus der Datenbank abrufen
$stmt = $pdo->query("SELECT id, name, email, benutzername, rolle FROM mitarbeiter ORDER BY id ASC");
$users = $stmt->fetchAll(PDO::FETCH_ASSOC);
?>
<!DOCTYPE html>
<html lang="de">
<head>
    <meta charset="UTF-8">
    <title>Benutzerverwaltung - SMP</title>
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <!-- Bootstrap CSS und Icons -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- Google Fonts -->
    <link href="https://fonts.googleapis.com/css2?family=Roboto:wght@400;500&display=swap" rel="stylesheet">
    <!-- Custom CSS -->
    <style>
        body {
            font-family: 'Roboto', sans-serif;
            background-color: #eef1f5;
            padding-bottom: 70px;
        }

        .container {
            max-width: 1000px;
            margin: 30px auto;
            background: #ffffff;
            padding: 25px;
            border-radius: 12px;
            box-shadow: 0 6px 8px rgba(0, 0, 0, 0.1);
        }

        .btn {
            border-radius: 6px;
        }

        .form-control {
            border-radius: 6px;
        }

        .navbar-brand {
            font-weight: 500;
        }

        /* Logo verkleinern */
        .navbar-brand img {
            height: 40px; /* Hier kannst du die gewünschte Höhe anpassen */
            width: auto;
        }

        .navbar-dark .navbar-nav .nav-link.active {
            color: #ffffff;
            font-weight: 500;
        }

        .table thead {
            background-color: #343a40;
            color: #ffffff;
        }

        .table tbody tr:hover {
            background-color: #f1f3f5;
        }

        .mobile-nav {
            display: none;
        }

        /* Mobile Navigation */
        @media (max-width: 767.98px) {
            .mobile-nav {
                display: flex;
                position: fixed;
                bottom: 0;
                left: 0;
                right: 0;
                background-color: #ffffff;
                box-shadow: 0 -2px 5px rgba(0, 0, 0, 0.1);
                padding: 5px 0;
                justify-content: space-around;
                z-index: 1000;
            }

            .mobile-nav a {
                flex: 1;
                color: #6c757d;
                text-decoration: none;
                font-size: 0.85rem;
                text-align: center;
                display: flex;
                flex-direction: column;
                align-items: center;
                padding: 8px 0;
            }

            .mobile-nav a i {
                font-size: 1.4rem;
                margin-bottom: 2px;
            }

            .mobile-nav a.active {
                color: #ffc107;
            }
        }
    </style>
</head>
<body>

<!-- Navigation für Desktop -->
<nav class="navbar navbar-expand-lg navbar-dark bg-dark d-none d-md-block">
  <div class="container-fluid">
    <a class="navbar-brand" href="index.php">
        <img src="img/logo.png" alt="Logo">
    </a>
    <div class="collapse navbar-collapse justify-content-end">
       <ul class="navbar-nav">
         <li class="nav-item">
             <a class="nav-link <?php echo (basename($_SERVER['PHP_SELF']) == 'dashboard.php') ? 'active' : ''; ?>" href="dashboard.php">
                 <i class="bi bi-speedometer2 me-2"></i>Dashboard
             </a>
         </li>
         <li class="nav-item">
             <a class="nav-link <?php echo (basename($_SERVER['PHP_SELF']) == 'aufgaben.php') ? 'active' : ''; ?>" href="aufgaben.php">
                 <i class="bi bi-list-task me-2"></i>Aufgaben
             </a>
         </li>
         <li class="nav-item">
             <a class="nav-link <?php echo (basename($_SERVER['PHP_SELF']) == 'lagerplaetze.php') ? 'active' : ''; ?>" href="lagerplaetze.php">
                 <i class="bi bi-box-seam me-2"></i>Lagerplätze
             </a>
         </li>
         <li class="nav-item">
             <a class="nav-link <?php echo (basename($_SERVER['PHP_SELF']) == 'bericht.php') ? 'active' : ''; ?>" href="bericht.php">
                 <i class="bi bi-bar-chart-fill me-2"></i>Berichte
             </a>
         </li>
         <?php if ($moduleInstalled): ?>
             <li class="nav-item">
                 <a class="nav-link <?php echo (basename($_SERVER['PHP_SELF']) == 'MODUL/index.php') ? 'active' : ''; ?>" href="MODUL/">
                     <i class="bi bi-box me-2"></i>Artikel
                 </a>
             </li>
         <?php endif; ?>
         <li class="nav-item">
             <a class="nav-link <?php echo (basename($_SERVER['PHP_SELF']) == 'settings.php') ? 'active' : ''; ?>" href="settings.php">
                 <i class="bi bi-gear-fill me-2"></i>Einstellungen
             </a>
         </li>
         <li class="nav-item">
             <a class="nav-link" href="logout.php">
                 <i class="bi bi-box-arrow-right me-2"></i>Abmelden
             </a>
         </li>
       </ul>
    </div>
  </div>
</nav>


<!-- Mobile Bottom Navigation -->
<div class="mobile-nav d-md-none">
    <a class="<?php echo (basename($_SERVER['PHP_SELF']) == 'dashboard.php') ? 'active' : ''; ?>" href="dashboard.php">
        <i class="bi bi-speedometer2"></i>
        Dashboard
    </a>
    <a class="<?php echo (basename($_SERVER['PHP_SELF']) == 'aufgaben.php') ? 'active' : ''; ?>" href="aufgaben.php">
        <i class="bi bi-list-task"></i>
        Aufgaben
    </a>
    <a class="<?php echo (basename($_SERVER['PHP_SELF']) == 'lagerplaetze.php') ? 'active' : ''; ?>" href="lagerplaetze.php">
        <i class="bi bi-box-seam"></i>
        Lagerplätze
    </a>
    <a class="<?php echo (basename($_SERVER['PHP_SELF']) == 'bericht.php') ? 'active' : ''; ?>" href="bericht.php">
        <i class="bi bi-bar-chart-fill"></i>
        Berichte
    </a>
    <?php if ($moduleInstalled): ?>
        <a class="<?php echo (basename($_SERVER['PHP_SELF']) == 'MODUL/index.php') ? 'active' : ''; ?>" href="MODUL/">
            <i class="bi bi-box"></i>
            Artikel
        </a>
    <?php endif; ?>
    <a class="<?php echo (basename($_SERVER['PHP_SELF']) == 'settings.php') ? 'active' : ''; ?>" href="settings.php">
        <i class="bi bi-gear-fill"></i>
        Einstellungen
    </a>
    <a href="logout.php">
        <i class="bi bi-box-arrow-right"></i>
        Abmelden
    </a>
</div>

<div class="container">
    <h2 class="text-center mb-4"><i class="bi bi-people-fill"></i> Benutzerverwaltung</h2>

    <?php if (!empty($message)): ?>
        <div class="alert alert-info">
            <?php echo htmlspecialchars($message); ?>
        </div>
    <?php endif; ?>

    <!-- Buttons und Suchfeld -->
    <div class="d-flex flex-wrap justify-content-between align-items-center mb-3">
        <div class="mb-2">
            <button type="button" class="btn btn-success" data-bs-toggle="modal" data-bs-target="#addUserModal">
                <i class="bi bi-plus-lg"></i> Neuen Benutzer hinzufügen
            </button>
        </div>
        <div class="mb-2">
            <input type="text" id="searchInput" class="form-control" placeholder="Benutzer suchen...">
        </div>
    </div>

    <!-- Tabelle mit Benutzern -->
    <div class="table-responsive">
        <table class="table table-hover align-middle">
            <thead>
                <tr>
                    <th>ID</th>
                    <th>Name</th>
                    <th>E-Mail</th>
                    <th>Benutzername</th>
                    <th>Rolle</th>
                    <th>Aktionen</th>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($users as $user): ?>
                    <tr>
                        <td><?php echo htmlspecialchars($user['id']); ?></td>
                        <td><?php echo htmlspecialchars($user['name']); ?></td>
                        <td><?php echo htmlspecialchars($user['email']); ?></td>
                        <td><?php echo htmlspecialchars($user['benutzername']); ?></td>
                        <td><?php echo htmlspecialchars($user['rolle']); ?></td>
                        <td>
                            <button type="button" class="btn btn-primary btn-sm me-1" data-bs-toggle="modal" data-bs-target="#editModal-<?php echo $user['id']; ?>">
                                <i class="bi bi-pencil-fill"></i> Bearbeiten
                            </button>
                            <form method="POST" class="d-inline" onsubmit="return confirm('Möchten Sie diesen Benutzer wirklich löschen?');">
                                <input type="hidden" name="user_id" value="<?php echo htmlspecialchars($user['id']); ?>">
                                <button type="submit" name="delete_user" class="btn btn-danger btn-sm">
                                    <i class="bi bi-trash-fill"></i> Löschen
                                </button>
                            </form>
                        </td>
                    </tr>

                    <!-- Modal zum Bearbeiten des Benutzers -->
                    <div class="modal fade" id="editModal-<?php echo $user['id']; ?>" tabindex="-1" aria-labelledby="editModalLabel-<?php echo $user['id']; ?>" aria-hidden="true">
                        <div class="modal-dialog">
                            <div class="modal-content">
                                <form method="POST">
                                    <div class="modal-header">
                                        <h5 class="modal-title" id="editModalLabel-<?php echo $user['id']; ?>">Benutzer bearbeiten</h5>
                                        <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Schließen"></button>
                                    </div>
                                    <div class="modal-body">
                                        <input type="hidden" name="user_id" value="<?php echo $user['id']; ?>">
                                        <div class="mb-3">
                                            <label for="name-<?php echo $user['id']; ?>" class="form-label">Name</label>
                                            <input type="text" name="name" id="name-<?php echo $user['id']; ?>" class="form-control" value="<?php echo htmlspecialchars($user['name']); ?>" required>
                                        </div>
                                        <div class="mb-3">
                                            <label for="email-<?php echo $user['id']; ?>" class="form-label">E-Mail</label>
                                            <input type="email" name="email" id="email-<?php echo $user['id']; ?>" class="form-control" value="<?php echo htmlspecialchars($user['email']); ?>" required>
                                        </div>
                                        <div class="mb-3">
                                            <label for="rolle-<?php echo $user['id']; ?>" class="form-label">Rolle</label>
                                            <select name="rolle" id="rolle-<?php echo $user['id']; ?>" class="form-select" required>
                                                <option value="user" <?php echo $user['rolle'] === 'user' ? 'selected' : ''; ?>>Benutzer</option>
                                                <option value="admin" <?php echo $user['rolle'] === 'admin' ? 'selected' : ''; ?>>Administrator</option>
                                            </select>
                                        </div>
                                        <!-- Optional: Passwort zurücksetzen -->
                                        <div class="mb-3">
                                            <label for="passwort-<?php echo $user['id']; ?>" class="form-label">Neues Passwort (optional)</label>
                                            <input type="password" name="passwort" id="passwort-<?php echo $user['id']; ?>" class="form-control">
                                        </div>
                                    </div>
                                    <div class="modal-footer">
                                        <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Abbrechen</button>
                                        <button type="submit" name="edit_user" class="btn btn-primary">Speichern</button>
                                    </div>
                                </form>
                            </div>
                        </div>
                    </div>
                <?php endforeach; ?>
            </tbody>
        </table>
    </div>
</div>

<!-- Modal zum Hinzufügen eines neuen Benutzers -->
<div class="modal fade" id="addUserModal" tabindex="-1" aria-labelledby="addUserModalLabel" aria-hidden="true">
    <div class="modal-dialog">
        <div class="modal-content">
            <form method="POST">
                <div class="modal-header">
                    <h5 class="modal-title" id="addUserModalLabel">Neuen Benutzer hinzufügen</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Schließen"></button>
                </div>
                <div class="modal-body">
                    <div class="mb-3">
                        <label for="add_name" class="form-label">Name</label>
                        <input type="text" name="name" id="add_name" class="form-control" required>
                    </div>
                    <div class="mb-3">
                        <label for="add_email" class="form-label">E-Mail</label>
                        <input type="email" name="email" id="add_email" class="form-control" required>
                    </div>
                    <div class="mb-3">
                        <label for="add_benutzername" class="form-label">Benutzername</label>
                        <input type="text" name="benutzername" id="add_benutzername" class="form-control" required>
                    </div>
                    <div class="mb-3">
                        <label for="add_passwort" class="form-label">Passwort</label>
                        <input type="password" name="passwort" id="add_passwort" class="form-control" required>
                    </div>
                    <div class="mb-3">
                        <label for="add_rolle" class="form-label">Rolle</label>
                        <select name="rolle" id="add_rolle" class="form-select" required>
                            <option value="user">Benutzer</option>
                            <option value="admin">Administrator</option>
                        </select>
                    </div>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Abbrechen</button>
                    <button type="submit" name="add_user" class="btn btn-success">Benutzer hinzufügen</button>
                </div>
            </form>
        </div>
    </div>
</div>

<!-- Bootstrap JS und Icons -->
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
<!-- Suchfunktion -->
<script>
document.getElementById('searchInput').addEventListener('keyup', function() {
    const searchValue = this.value.toLowerCase();
    const rows = document.querySelectorAll('table tbody tr');
    rows.forEach(row => {
        const cells = Array.from(row.getElementsByTagName('td'));
        const match = cells.some(cell => cell.textContent.toLowerCase().includes(searchValue));
        row.style.display = match ? '' : 'none';
    });
});
</script>
</body>
</html>
